@@ -128,7 +128,7 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0039   => "Could not find wal file on this node: [0]\n",
     SLAVESTART_MS0040   => "Could not find wal file on another node: [0]\n",
     SLAVESTART_MS0041   => "This node is advancing in XLOG location against the peer node ([0] > [1]).\n",
-    SLAVESTART_MS0042   => "Could not find latest history file on another node: [0]\n",
+    SLAVESTART_MS0042   => "No timeline history files found on another node.\n",
     SLAVESTART_MS0043   => "There are no history that has passed through TimeLineID on this node in the content of history file (\"[0]\") of TimeLineID on another node.\n",
     SLAVESTART_MS0044   => "There are no history that has passed through the location of xlog on this node in the content of history file (\"[0]\") of TimeLineID on another node.\n",
     SLAVESTART_MS0045   => "This node needs to be reinitialized from a new base backup.\n",
@@ -165,6 +165,7 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0074   => "pg_rewind failed to connect to the peer\n - TCP Forwarding may be disabled in sshd_config on the peer server\n",
     SLAVESTART_MS0075   => "This database cluster is incompletely rewinded by pg-rex_slave_start.\n",
     SLAVESTART_MS0076   => "WAL files with future XLOG location of the peer node found in archive directory.\n",
+    SLAVESTART_MS0087   => "Timeline hitory file for timeline ID [0] not found on another node: [1]\n",
     SLAVESTART_MS0099   => "Internal Error.\n",
 
     STOP_USAGE  => <<_STOP_USAGE_,
@@ -357,14 +358,14 @@ _SWITCHOVER_USAGE_
     COMMON_MS0030       => "\nPassword has been entered.\n",
     COMMON_MS0031       => "Could not find password file (\"[0]\").\n",
     COMMON_MS0032       => "Failed to read password file (\"[0]\").\n",
-    COMMON_MS0033       => "SSH password is invalid.\n",
+    COMMON_MS0033       => "Content of password file (\"[0]\") is invalid.\n",
     COMMON_MS0034       => "Should specify [0] which is setting either\n".
                            "manual, passfile or nopass in pg-rex_tools.conf.\n",
     COMMON_MS0035       => "Authority of the password file \"[0]\" is not 600.\n",
     COMMON_MS0036       => "Not found PostgreSQL commands in specified PGPATH ([0]).\n".
                            "Should specify PGPATH correctly in pg-rex_tools.conf.\n",
     COMMON_MS0037       => "PostgreSQL [0] is not supported.\n".
-                           "Please use version 9.4 or 9.5.\n",
+                           "Please use version 9.5 or 9.6.\n",
     COMMON_MS0038       => "Pacemaker [0] is not supported.\n".
                            "Please use version 1.1.\n",
     COMMON_MS0039       => "Not found network interface to correspond to bindnetaddr ([1]) on [0].\n",
@@ -380,6 +381,7 @@ _SWITCHOVER_USAGE_
     COMMON_MS0049       => "[0] has already started on this node.\n",
     COMMON_MS0050       => "Failed to create lock file([0]).\n",
     COMMON_MS0051       => "Failed to delete lock file([0]). : [1]\n",
+    COMMON_MS0052       => "[0] is not in IPv4 format.\n",
 };
 
 1;
